@@ -3,16 +3,24 @@ use strict;
 use warnings;
 use Exporter ();
 
-our $VERSION = '1.500004';
+our $VERSION = '1.500005';
 $VERSION =~ tr/_//d;
 
 our @EXPORT_OK = qw(
-  first min max minstr maxstr reduce sum shuffle
-  all any none notall product sum0 uniq uniqnum uniqstr
+  first min max minstr maxstr reduce reductions sum sample shuffle
+  all any none notall product sum0 uniq uniqnum uniqint uniqstr
   pairs unpairs pairkeys pairvalues pairmap pairgrep pairfirst
   head tail
+  zip zip_longest zip_shortest
+  mesh mesh_longest mesh_shortest
 );
 
+my $rand = do { our $RAND };
+*RAND = *List::Util::RAND;
+our $RAND;
+$RAND = $rand
+  if !defined $RAND;
+
 sub import {
   my $pkg = caller;
 
@@ -22,6 +30,14 @@ sub import {
   ${"${pkg}::a"} = ${"${pkg}::a"};
   ${"${pkg}::b"} = ${"${pkg}::b"};
 
+  # May be imported by List::Util if very old version is installed, which
+  # expects default exports
+  if ($pkg eq 'List::Util' && @_ < 2) {
+    package #hide from PAUSE
+      List::Util;
+    return __PACKAGE__->import(qw(first min max minstr maxstr reduce sum shuffle));
+  }
+
   goto &Exporter::import;
 }
 
@@ -49,6 +65,34 @@ sub reduce (&@) {
   $a;
 }
 
+sub reductions (&@) {
+  my $f = shift;
+  unless ( length ref $f && eval { $f = \&$f; 1 } ) {
+    require Carp;
+    Carp::croak("Not a subroutine reference");
+  }
+
+  return unless @_;
+  return shift unless @_ > 1;
+
+  my $pkg = caller;
+  my $a = shift;
+
+  no strict 'refs';
+  local *{"${pkg}::a"} = \$a;
+  my $glob_b = \*{"${pkg}::b"};
+
+  my @o = $a;
+
+  foreach my $b (@_) {
+    local *$glob_b = \$b;
+    $a = $f->();
+    push @o, $a;
+  }
+
+  @o;
+}
+
 sub first (&@) {
   my $f = shift;
   unless ( length ref $f && eval { $f = \&$f; 1 } ) {
@@ -102,13 +146,16 @@ sub maxstr (@) {
 }
 
 sub shuffle (@) {
-  my @a=\(@_);
-  my $n;
-  my $i=@_;
-  map {
-    $n = rand($i--);
-    (${$a[$n]}, $a[$n] = $a[$i])[0];
-  } @_;
+  sample(scalar @_, @_);
+}
+
+sub sample ($@) {
+  my $num = shift;
+  my @i = (0 .. $#_);
+  $num = @_ if $num > @_;
+  my @o = defined $RAND ? (map +(splice @i, $RAND->($#i), 1), 1 .. $num)
+                        : (map +(splice @i,    rand($#i), 1), 1 .. $num);
+  @_[@o];
 }
 
 sub all (&@) {
@@ -299,7 +346,7 @@ sub uniqnum (@) {
       my ($NV) = unpack 'F', pack 'F', $_;
       !$seen{
         $NV == 0 ? 0 : (
-          (!($NV != $NV)
+          ($NV == $NV
             ? do { local $@; eval { pack 'JF', $_, $_ } }
             : 0
           ) || sprintf('%f', $_)
@@ -312,6 +359,25 @@ sub uniqnum (@) {
   @uniq;
 }
 
+sub uniqint (@) {
+  my %seen;
+  my @uniq =
+    map +(
+      ref $_ ? $_ : int($_)
+    ),
+    grep {
+      !$seen{
+        /\A[0-9]+\z/  ? $_
+        : $_ > 0      ? sprintf '%u', $_
+                      : sprintf '%d', $_
+      }++;
+    }
+    map +(defined($_) ? $_
+      : do { warnings::warnif('uninitialized', 'Use of uninitialized value in subroutine entry'); 0 }),
+    @_;
+  @uniq;
+}
+
 sub uniqstr (@) {
   my %seen;
   my @uniq =
@@ -336,6 +402,38 @@ sub tail ($@) {
   @_[ ( $size >= 0 ? ($#_ - ($size-1) ) : 0 - $size ) .. $#_ ];
 }
 
+sub zip_longest {
+  map {
+    my $idx = $_;
+    [ map $_->[$idx], @_ ];
+  } ( 0 .. max(map $#$_, @_) || -1 )
+}
+
+sub zip_shortest {
+  map {
+    my $idx = $_;
+    [ map $_->[$idx], @_ ];
+  } ( 0 .. min(map $#$_, @_) || -1 )
+}
+
+*zip = \&zip_longest;
+
+sub mesh_longest {
+  map {
+    my $idx = $_;
+    map $_->[$idx], @_;
+  } ( 0 .. max(map $#$_, @_) || -1 )
+}
+
+sub mesh_shortest {
+  map {
+    my $idx = $_;
+    map $_->[$idx], @_;
+  } ( 0 .. min(map $#$_, @_) || -1 )
+}
+
+*mesh = \&mesh_longest;
+
 1;
 
 __END__
@@ -346,17 +444,15 @@ List::Util::PP - Pure-perl implementations of List::Util subroutines
 
 =head1 SYNOPSIS
 
-    use List::Util::PP qw(
-      reduce any all none notall first
+  use List::Util::PP qw(
+    reduce any all none notall first reductions
 
-      max maxstr min minstr product sum sum0
+    max maxstr min minstr product sum sum0
 
-      pairs pairkeys pairvalues pairfirst pairgrep pairmap
+    pairs unpairs pairkeys pairvalues pairfirst pairgrep pairmap
 
-      shuffle
-
-      head tail
-    );
+    shuffle uniq uniqint uniqnum uniqstr zip mesh
+  );
 
 =head1 DESCRIPTION
 
@@ -394,16 +490,22 @@ this module otherwise.
 
 =item L<reduce|List::Util/reduce>
 
+=item L<reductions|List::Util/reductions>
+
 =item L<sum|List::Util/sum>
 
 =item L<sum0|List::Util/sum0>
 
 =item L<shuffle|List::Util/shuffle>
 
+=item L<sample|List::Util/sample>
+
 =item L<uniq|List::Util/uniq>
 
 =item L<uniqnum|List::Util/uniqnum>
 
+=item L<uniqint|List::Util/uniqint>
+
 =item L<uniqstr|List::Util/uniqstr>
 
 =item L<pairs|List::Util/pairs>
@@ -424,6 +526,30 @@ this module otherwise.
 
 =item L<tail|List::Util/tail>
 
+=item L<zip|List::Util/zip>
+
+=item L<zip_longest|List::Util/zip>
+
+=item L<zip_shortest|List::Util/zip>
+
+=item L<mesh|List::Util/mesh>
+
+=item L<mesh_longest|List::Util/mesh>
+
+=item L<mesh_shortest|List::Util/mesh>
+
+=back
+
+=head1 CONFIGURATION VARIABLES
+
+=over 4
+
+=item L<$RAND|List::Util/$RAND>
+
+The variables C<$List::Util::RAND>, C<$List::Util::PP::RAND>, and
+C<$List::Util::MaybeXS::RAND> are all aliased to each other.  Any of them will
+impact both List::Util::PP and L<List::Util> functions.
+
 =back
 
 =head1 SUPPORT
